# NEMO_User_Chemicals

Adapted from Princeton University's user chemicals feature.
Original code:  https://gitlab.com/mnfc-princeton/NEMO/-/blob/master/NEMO/views/user_chemicals.py

Setup instructions:
1) Add NEMO_user_chemicals to installed apps in settings.py
2) Install this plugin by running pip install NEMO-user-chemicals
3) Add the Chemical Dashboard (/chemical_dashboard/) as a landing page choice
4) Add email addresses and templates to customizations